pub struct SurfpoolSubgraphPlugin {
pub uuid: Uuid,
/* private fields */
}Fields
uuid: UuidTrait Implementations
Sourceimpl Debug for SurfpoolSubgraphPlugin
impl Debug for SurfpoolSubgraphPlugin
Sourceimpl Default for SurfpoolSubgraphPlugin
impl Default for SurfpoolSubgraphPlugin
Sourcefn default() -> SurfpoolSubgraphPlugin
fn default() -> SurfpoolSubgraphPlugin
Returns the “default value” for a type. Read more
Sourceimpl GeyserPlugin for SurfpoolSubgraphPlugin
impl GeyserPlugin for SurfpoolSubgraphPlugin
fn name(&self) -> &'static str
Sourcefn on_load(&mut self, config_file: &str, _is_reload: bool) -> PluginResult<()>
fn on_load(&mut self, config_file: &str, _is_reload: bool) -> PluginResult<()>
The callback called when a plugin is loaded by the system,
used for doing whatever initialization is required by the plugin.
The _config_file contains the name of the
of the config file. The config must be in JSON format and
include a field “libpath” indicating the full path
name of the shared library implementing this interface.
Sourcefn on_unload(&mut self)
fn on_unload(&mut self)
The callback called right before a plugin is unloaded by the system
Used for doing cleanup before unload.
Sourcefn notify_end_of_startup(&self) -> PluginResult<()>
fn notify_end_of_startup(&self) -> PluginResult<()>
Called when all accounts are notified of during startup.
Sourcefn update_account(
&self,
account: ReplicaAccountInfoVersions<'_>,
slot: Slot,
_is_startup: bool,
) -> PluginResult<()>
fn update_account( &self, account: ReplicaAccountInfoVersions<'_>, slot: Slot, _is_startup: bool, ) -> PluginResult<()>
Called when an account is updated at a slot.
When
is_startup is true, it indicates the account is loaded from
snapshots when the validator starts up. When is_startup is false,
the account is updated during transaction processing.Sourcefn update_slot_status(
&self,
_slot: Slot,
_parent: Option<u64>,
_status: &SlotStatus,
) -> PluginResult<()>
fn update_slot_status( &self, _slot: Slot, _parent: Option<u64>, _status: &SlotStatus, ) -> PluginResult<()>
Called when a slot status is updated
Sourcefn notify_transaction(
&self,
transaction: ReplicaTransactionInfoVersions<'_>,
slot: Slot,
) -> PluginResult<()>
fn notify_transaction( &self, transaction: ReplicaTransactionInfoVersions<'_>, slot: Slot, ) -> PluginResult<()>
Called when a transaction is processed in a slot.
Sourcefn notify_entry(&self, _entry: ReplicaEntryInfoVersions<'_>) -> PluginResult<()>
fn notify_entry(&self, _entry: ReplicaEntryInfoVersions<'_>) -> PluginResult<()>
Called when an entry is executed.
Sourcefn notify_block_metadata(
&self,
_blockinfo: ReplicaBlockInfoVersions<'_>,
) -> PluginResult<()>
fn notify_block_metadata( &self, _blockinfo: ReplicaBlockInfoVersions<'_>, ) -> PluginResult<()>
Called when block’s metadata is updated.
Sourcefn account_data_notifications_enabled(&self) -> bool
fn account_data_notifications_enabled(&self) -> bool
Check if the plugin is interested in account data
Default is true – if the plugin is not interested in
account data, please return false.
Sourcefn transaction_notifications_enabled(&self) -> bool
fn transaction_notifications_enabled(&self) -> bool
Check if the plugin is interested in transaction data
Default is false – if the plugin is interested in
transaction data, please return true.
Sourcefn entry_notifications_enabled(&self) -> bool
fn entry_notifications_enabled(&self) -> bool
Check if the plugin is interested in entry data
Default is false – if the plugin is interested in
entry data, return true.
Sourcefn setup_logger(
&self,
logger: &'static dyn Log,
level: LevelFilter,
) -> Result<(), GeyserPluginError>
fn setup_logger( &self, logger: &'static dyn Log, level: LevelFilter, ) -> Result<(), GeyserPluginError>
The callback to allow the plugin to setup the logging configuration using the logger
and log level specified by the validator. Will be called first on load/reload, before any other
callback, and only called once. Read more
Sourcefn account_data_snapshot_notifications_enabled(&self) -> bool
fn account_data_snapshot_notifications_enabled(&self) -> bool
Check if the plugin is interested in account data from snapshot
Default is true – if the plugin is not interested in
account data snapshot, please return false because startup would be
improved significantly.